.. Tests that using a Table of Contents directive renders correctly

.. contents::

Features
========

* Eats cheese

Installation
============

Requirements
------------

* Teeth
* Good taste

Let's eat some cheese together!
